
This Repository hold classes and script used for integration tests

There is need to use this repository unless you want to run some or all integration tests locally

Documentation
-------------
[TestBase documentation](https://spinnakertestbase.readthedocs.io/en/7.1.0)

[Combined PyNN8 python documentation (Excluding TestBase)](http://spinnakermanchester.readthedocs.io/en/7.1.0)

